@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: i18n.py 11603 2019-06-02 12:30:54Z Trista $
+# $Id: i18n.py 12691 2021-01-14 12:04:58Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, and individual contributors.
 # All rights reserved.
@@ -30,9 +30,9 @@
 # OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #
-# $Author: Trista $ (last)
-# $Date: 2019-06-02 20:30:54 +0800 (日, 02  6 2019) $
-# $Revision: 11603 $
+# $Author: Lavender $ (last)
+# $Date: 2021-01-14 21:04:58 +0900 (週四, 14 一月 2021) $
+# $Revision: 12691 $
 
 from django.core.management.base import BaseCommand, CommandError
 from optparse import make_option
@@ -109,10 +109,17 @@ class Command(BaseCommand):
                     info.append((app, root))
                 if '.svn' in dirs:
                     dirs.remove('.svn')  # Don't visit .svn directories.
-
+                    
+        defaultBabelPath = os.path.join(
+            os.path.dirname(os.path.dirname(os.path.dirname(os.path.abspath(__file__)))), 
+            "babel.cfg"
+        )
+        
         def exeCmd(cmd, path='.'):
             print("cd %s" % path)
             os.chdir(path)
+            if not os.path.exists("babel.cfg"):
+                cmd = cmd.replace("babel.cfg", defaultBabelPath)
             print(cmd)
             os.system(cmd)
             print("cd %s" % curdir)
@@ -127,8 +134,8 @@ class Command(BaseCommand):
 
         def po():
             # Extract messages to .pot.
-            extractCmd = ("%s extract %s -F babel.cfg -o locale/%s.pot ."
-                          % (pyBabelPath, extractArgs, catalog))
+            extractCmd = ("%s extract -F babel.cfg -o locale/%s.pot ."
+                          % (pyBabelPath, catalog))
             exeCmd(extractCmd)
 
             for app, path in info:
